# coding: utf-8

import os
import re

from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

filename = ['thx', 'luca', '__init__.py']
with open(os.path.join(os.getcwd(), *filename)) as f:
    VERSION = re.compile(r'.*__version__ = "(.*?)"', re.S).match(f.read()).group(1)


def get_data_files(*args, **kwargs):
    EXT_PATTERN = (
        kwargs.get('ext')
        or '\.(html|js|txt|css|po|mo|png|json|xml|yml|conf|css_t)')

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name.replace('.', '/')):
            rel_dirpath = re.sub("^" + pkg_name + '/', '',  dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'): del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    return data_dict


setup(
    name='thx-luca',
    version=VERSION,
    url='https://hg.thux.dev/thux/apps/thx.luca',
    description='Luca Comunica',
    long_description=readme,
    author='Thux',
    author_email='code@thux.it',
    packages=['thx.luca'],
    zip_safe=False,
    install_requires=[

    ],
    package_data=get_data_files('thx-luca')
)
